@@ -5,7 +5,7 @@ use warnings;
 use File::Spec;
 use File::Temp;
 use File::Copy;
-use Data::Dumper;
+use Text::Diff ();
 
 =encoding utf8
 
@@ -108,6 +108,10 @@ The reference's numbers found in the body as a long string.
 
 The footnote' numbers found in the body as a long string.
 
+=item differences
+
+The unified diff between the footnotes and the references' list
+
 =back
 
 =cut
@@ -177,7 +181,6 @@ sub tmpdir {
 
 sub process {
     my $self = shift;
-    print Dumper($self) if $self->debug;
     # auxiliary files
     my $tmpdir = $self->tmpdir;
     print "Using $tmpdir\n" if $self->debug;
@@ -285,6 +288,9 @@ sub rewrite {
                            footnotes_found  => join(" ",
                                                     map { $open . $_ . $close }
                                                     @footnotes_found),
+                           differences => Text::Diff::diff([ map { $open . $_ . $close . "\n" } @footnotes_found  ],
+                                                           [ map { $open . $_ . $close . "\n" } @references_found ],
+                                                           { STYLE => 'Unified' }),
                           });
         return;
     }
